@@ -2,9 +2,9 @@
 # Mail::SPF::Util
 # Mail::SPF utility class.
 #
-# (C) 2005-2006 Julian Mehnle <julian@mehnle.net>
+# (C) 2005-2007 Julian Mehnle <julian@mehnle.net>
 #     2005      Shevek <cpan@anarres.org>
-# $Id: Util.pm 30 2006-11-27 19:55:10Z Julian Mehnle $
+# $Id: Util.pm 40 2007-01-10 00:00:42Z Julian Mehnle $
 #
 ##############################################################################
 
@@ -19,6 +19,8 @@ Mail::SPF::Util - Mail::SPF utility class
 use warnings;
 use strict;
 
+use utf8;  # Hack to keep Perl 5.6 from whining about /[\p{}]/.
+
 use base 'Mail::SPF::Base';
 
 use Mail::SPF::Exception;
@@ -223,11 +225,9 @@ B<false>.
 
 =cut
 
-use constant {
-    valid_domain_match_none         => 0,
-    valid_domain_match_subdomain    => 1,
-    valid_domain_match_identical    => 2
-};
+use constant valid_domain_match_none        => 0;
+use constant valid_domain_match_subdomain   => 1;
+use constant valid_domain_match_identical   => 2;
 
 sub valid_domain_for_ip_address {
     my ($self, $server, $ip_address, $domain, $find_best_match, $accept_any_domain) = @_;
